@@ -1,8 +1,11 @@
+import os
 import sys
 import argparse
+from typing import List
 from . import run_transform_inline
 import json
 from mlflow import start_run
+import base64
 
 def main():
     parser = argparse.ArgumentParser()
@@ -18,15 +21,21 @@ def main():
             if (len(oup) == 2):
                 kwa[oup[0]] = oup[1]
     print(str(kwa))
-    input_data_spec = json.loads(args.input_data_spec)
+    if args.input_data_spec.startswith('base64:'):
+        input_data_spec = json.loads(base64.b64decode(args.input_data_spec[7:]).decode('utf-8'))
+    else:
+        input_data_spec = json.loads(args.input_data_spec)
+    retval = None  # assign to avoid the error: 'variable used before assignment' in the 'return' statement below
     if (len(kwa.items()) > 0):
         with start_run() as run:
-            return run_transform_inline(args.service, run.info.run_id,
+            retval = run_transform_inline(args.service, run.info.run_id,
                 input_data_spec, args.xformname, **kwa)
     else:
         with start_run() as run:
-            return run_transform_inline(args.service, run.info.run_id,
+            retval = run_transform_inline(args.service, run.info.run_id,
                 input_data_spec, args.xformname)
+    
+    return retval
 
 if __name__ == "__main__":
     main()
